<?php
/**
* @project ApPHP WebsiteCleaner
* @copyright (c) 2014 ApPHP
* @author ApPHP <info@apphp.com>
* @license http://www.gnu.org/licenses/
*/

// Initialize the session
session_start();

@date_default_timezone_set('America/Los_Angeles');

include('include/settings.inc.php');
include('include/functions.inc.php');

// check and set token
$token_post = isset($_POST['token']) ? $_POST['token'] : 'post';
$token_session = isset($_SESSION['token']) ? $_SESSION['token'] : 'session';
if(isset($_SERVER['REQUEST_METHOD']) && $_SERVER['REQUEST_METHOD'] == 'POST'){
    if($token_session != $token_post){
        unset($_POST['task']);
    }
}

$token = md5(uniqid(rand(), true));	
$_SESSION['token'] = $token;


// retrieve parameters 
$directoryPath = isset($_POST['settings_directory_path']) ? $_POST['settings_directory_path'] : '';
$includeSubDirectories = isset($_POST['settings_include_subdirectories']) ? (bool)$_POST['settings_include_subdirectories'] : '';
$cache = isset($_POST['settings_cache']) ? (bool)$_POST['settings_cache'] : false;
$thumb = isset($_POST['settings_thumb']) ? (bool)$_POST['settings_thumb'] : false;
$errorlog = isset($_POST['settings_errorlog']) ? (bool)$_POST['settings_errorlog'] : false;
$infected = isset($_POST['settings_infected']) ? $_POST['settings_infected'] : '';
$changed = isset($_POST['settings_changed']) ? (bool)$_POST['settings_changed'] : false;
$task = isset($_POST['task']) ? $_POST['task'] : '';
$msg = '';
$tasksCount = 1;
$result = false;

// set search array
$settings = array(
    'general'=>array('running_time'=>'0', 'check_subdirectories'=>$includeSubDirectories, 'files_checked'=>0, 'directories_checked'=>0),
    'cache'=>array('enabled'=>true, 'active'=>$cache, 'total_found'=>0, 'found_files'=>array(), 'file_extension'=>_CACHE_FILE_EXTENSION, 'allow_deleting'=>_CACHE_ALLOW_DELETING),
    'thumb'=>array('enabled'=>true, 'active'=>$thumb, 'total_found'=>0, 'found_files'=>array(), 'allow_deleting'=>_THUMB_ALLOW_DELETING),
    'errorlog'=>array('enabled'=>true, 'active'=>$errorlog, 'total_found'=>0, 'found_files'=>array(), 'file_name'=>_ERRORLOG_FILE_NAME, 'allow_deleting'=>_ERRORLOG_ALLOW_DELETING),
    'infected'=>array('enabled'=>true, 'active'=>$infected, 'total_found'=>0, 'found_files'=>array(), 'search_string'=>_INFECTED_SEARCH_STRING, 'replace_string'=>_INFECTED_REPLACE_STRING, 'allowed_extensions'=>$_INFECTED_ALLOWED_EXTENSIONS, 'allow_deleting'=>_INFECTED_ALLOW_DELETING, 'allow_cleaning'=>_INFECTED_ALLOW_CLEANING),
    'changed'=>array('enabled'=>true, 'active'=>$changed, 'total_found'=>0, 'found_files'=>array(), 'diff_hours'=>_CHANGED_DIFF_HOURS, 'ignore_cache_files'=>_CHANGED_IGNORE_CACHE_FILES),
);


if($task != ''){
    if(!$directoryPath){
        $msg = '<p class="text-warning">No directory path is entered! Please enter a valid path to destination directory.</p>';    
    }else if(!$cache && !$thumb && !$changed && !$errorlog && !$infected){
        $msg = '<p class="text-warning">No options selected! Please select at least one option to check your site.</p>';    
    }        

    if($task == 'check'){
        $directoryPath = trim($directoryPath, '/').'/';

        $startTime = wscGetFormattedMicrotime();            
        $result = wscCheckRecursive($directoryPath, $settings, 'check', 'view');
        $finishTime = wscGetFormattedMicrotime();
        $settings['general']['running_time'] = round((float)$finishTime - (float)$startTime, 5);

        if($result){
            // OK!
        }else{
            $msg = '<p class="text-error">Wrong destination directory path! Please re-enter.</p>';
        }
    }
}    

?>
<!DOCTYPE html>
<html lang="en"><head>
    <meta http-equiv="content-type" content="text/html; charset=UTF-8">
    <meta charset="utf-8">
    <title>ApPHP WebsiteCleaner - Index</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="keywords" content="php web cleaner, php site cleaner, web malware cleaner, online site cleaner" />   
    <meta name="description" content="Powerful and easy to use website malware cleanup utility" />
    <meta name="author" content="ApPHP Company">

    <link href="bootstrap/bootstrap.css" rel="stylesheet">
    <link href="css/main.css" rel="stylesheet">
    <link href="bootstrap/bootstrap-responsive.css" rel="stylesheet">

    <!-- icons -->
    <link rel="shortcut icon" href="images/apphp.ico">
</head>
<body id="top">

    <div class="container-narrow">
        
        <div class="masthead">
            <ul class="nav nav-pills pull-right">
                <li class="active"><a href="index.php">Home</a></li>
                <li><a href="javascript:void(0);" onclick="javascript:wscScrollTo('description')">Description</a></li>
                <li><a href="http://www.apphp.com/php-website-cleaner/index.php" target="_new" title="Opens in new window">About <i class="icon-share"></i></a></li>
            </ul>
            <h3 class="muted">ApPHP WebsiteCleaner <small>v1.0.2</small></h3>
        </div>
        <hr>
        
        <div class="jumbotron">
            <h1>Super awesome cleaner for your website!</h1>
            <p class="lead">
                This script allows you to check your website has got infected with Web-malware.
                Generally it takes days to clean up a site and get rid of pesky javascripts,
                iframes, and other general malware.
                <br>
                Now you may do it within minutes! 
            </p>
            <a class="btn btn-large btn-success" href="javascript:void(0);" onclick="javascript:wscScrollTo('settings')">Click to Start!</a>
            <br><br>
        </div>
        <hr>

        
        <div id="description">
            <h2>Description & Features</h2>    
        </div>        
        <div class="row-fluid marketing">
            <div class="span6">
                <h4>PHP Code infections</h4>
                <p>Finds and cleans malicious PHP code injections on the whole site or in selected directory.</p>
                <h4>JS Code infections</h4>
                <p>Finds and cleans malicious JavaScript code injections on the whole site or in selected directory.</p>
                <h4>Cache Files</h4>
                <p>Finds cache files (files with special extension) on the site and removes them.</p>
            </div>
            <div class="span6">
                <h4>HTML infections</h4>
                <p>Finds and cleans malicious HTML code injections in all types of files.</p>
                <h4>Changed Files</h4>
                <p>Finds all files that were changed in the specified period of time.</p>
                <h4>Unneeded Files</h4>
                <p>Finds all unneded files (files with special extension like thumb.db or error logs) on the site and removes them.</p>
            </div>
        </div>
        <hr>

        <div id="settings" class="row-fluid">
            <h2>Set Configuration</h2>
            
            Please select the required operations you want to perform before you run the check.<br>
            Be careful when deleting unneeded files - this may harm your computer.
            <br>
            <?php echo (_MODE == 'demo') ? '<p class="text-error"><strong>ATTENTION</strong>: this script is currently running in DEMO mode!</p>' : '<br>'; ?>            

            <div class="span11" style="margin-left:1px;">
                
                <?php                
                    echo $msg;
                    if($result){
                        echo '<p class="text-info">';
                        echo 'Total files checked: '.$settings['general']['files_checked'].'<br>';
                        echo 'Total sub-directories checked: '.$settings['general']['directories_checked'].'<br>';
                        echo 'Total running time: '.$settings['general']['running_time'].' sec.';
                        echo '</p>';
                    }
                ?>        

                <form id="frmSiteCheck" action="index.php#settings" method="post">
                    <input type="hidden" name="task" value="check" />
                    <input type="hidden" name="token" value="<?php echo $token; ?>" />
                    
                    <h5><?php echo $tasksCount++; ?>. Enter a path to destination directory: <a href="javascript:void(0);" data-toggle="tooltip" title="Example: ../ or modules/ or ../modules/files/"><i class="icon-question-sign"></i></a></h5>
                    <input type="text" name="settings_directory_path" class="input-block-level input-xxlarge" <?php echo (_MODE == 'demo') ? 'readonly="readonly"' : ''; ?> value="<?php echo (_MODE == 'demo') ? 'test/' : htmlentities($directoryPath); ?>" placeholder="relative/path/to/destination/directory/">
                    <label class="checkbox">                    
                    <input type="checkbox"<?php echo ($includeSubDirectories ? ' checked="checked"' : ''); ?> name="settings_include_subdirectories" value="1"> include sub-directories
                    </label>                    
                    
                    <?php if($settings['cache']['enabled']){?>    
                    <h5><?php echo $tasksCount++; ?>. Search for cache files:</h5>
                    <label class="checkbox">                    
                    <input type="checkbox"<?php echo ($cache ? ' checked="checked"' : ''); ?>  name="settings_cache" value="1"> select this option to search for files with <?php echo $settings['cache']['file_extension'] ? '<code>'.$settings['cache']['file_extension'].'</code> extension' : '<span class="text-error">no settings defined</span>'; ?>
                    </label>                
                    <?php
                        if($settings['cache']['enabled'] && $cache && $result){
                            echo wscDrawResult($settings, 'cache', $settings['cache']['allow_deleting']);
                        };
                    }
                    ?>                    
                    
                    <?php if($settings['thumb']['enabled']){?>
                    <h5><?php echo $tasksCount++; ?>. Search for thumb files:</h5>
                    <label class="checkbox">                    
                    <input type="checkbox"<?php echo ($thumb ? ' checked="checked"' : ''); ?>  name="settings_thumb" value="1"> select this option to search for thumb files (files named as <code>thumb.db</code>)
                    </label>
                    <?php
                        if($thumb && $result){
                            echo wscDrawResult($settings, 'thumb', $settings['thumb']['allow_deleting']);
                        };
                    }
                    ?>                    
                    
                    <?php if($settings['errorlog']['enabled']){?>
                    <h5><?php echo $tasksCount++; ?>. Search for error log files:</h5>
                    <label class="checkbox">                    
                    <input type="checkbox"<?php echo ($errorlog ? ' checked="checked"' : ''); ?>  name="settings_errorlog" value="1"> select this option to search for error log files (<?php echo $settings['errorlog']['file_name'] ? 'files named as <code>'.$settings['errorlog']['file_name'].'</code>' : '<span class="text-error">no settings defined</span>'; ?>)
                    </label>
                    <?php                       
                        if($errorlog && $result){
                            echo wscDrawResult($settings, 'errorlog', $settings['errorlog']['allow_deleting']);
                        };
                    }                        
                    ?>                    

                    <?php if($settings['infected']['enabled']){?>
                    <h5><?php echo $tasksCount++; ?>. Search for infected files:</h5>
                    <label class="checkbox">
                    <input type="checkbox"<?php echo ($infected ? ' checked="checked"' : ''); ?> name="settings_infected" value="1"> select this option to search for infected files (<?php echo $settings['infected']['search_string'] ? 'files that include <code>'.htmlentities(wscCreateShortenName($settings['infected']['search_string'], 10)).'</code>' : '<span class="text-error">no settings defined</span>'; ?>)
                    </label>
                    <?php
                        if($infected !== '' && $result){
                            echo wscDrawResult($settings, 'infected', $settings['infected']['allow_deleting'], $settings['infected']['allow_cleaning']);
                        };
                    }                        
                    ?>                    

                    <?php if($settings['changed']['enabled']){?>
                    <h5><?php echo $tasksCount++; ?>. Search for last changed files:</h5>
                    <label class="checkbox">                    
                    <input type="checkbox"<?php echo ($changed ? ' checked="checked"' : ''); ?>  name="settings_changed" value="1"> select this option to search for files changed in last <?php echo (int)$settings['changed']['diff_hours']; ?> hours
                    </label>
                    <?php                       
                        if($changed && $result){
                            echo wscDrawResult($settings, 'changed', false);
                        };
                    }                        
                    ?>                    
                    

                    <br><br><br>
                    <a class="btn btn-primary tn-large" id="btnCheckNow" href="javascript:void(0);">Check Now My Website!</a>
                    <?php                
                        if($result){
                            echo '<span id="start-over-conteiner">';
                            echo '&nbsp;&nbsp; - or - &nbsp;&nbsp;<a href="index.php">Start Over <i class="icon-refresh"></i></a>';
                            echo '</span>';
                        }
                    ?>                    
                </form>
            
                <br><br><br><br>
            </div>
        </div>
        <hr>
        
        
        <div class="footer">
            <p>
                ApPHP WebsiteCleaner &copy; ApPHP <?php echo @date('Y'); ?>
                <a href="javascript:void(0)" onclick="javascript:wscScrollTo('top')" class="pull-right">top <i class="icon-circle-arrow-up"></i></a>                
            </p>            
        </div>
    </div> <!-- /container -->

    <!-- javascript
    ================================================== -->
    <!-- Placed at the end of the document so the pages load faster -->
    <script src="bootstrap/jquery.js"></script>
    <script src="bootstrap/bootstrap-transition.js"></script>
    <script src="bootstrap/bootstrap-alert.js"></script>
    <script src="bootstrap/bootstrap-modal.js"></script>
    <script src="bootstrap/bootstrap-dropdown.js"></script>
    <script src="bootstrap/bootstrap-scrollspy.js"></script>
    <script src="bootstrap/bootstrap-tab.js"></script>
    <script src="bootstrap/bootstrap-tooltip.js"></script>
    <script src="bootstrap/bootstrap-popover.js"></script>
    <script src="bootstrap/bootstrap-button.js"></script>
    <script src="bootstrap/bootstrap-collapse.js"></script>
    <script src="bootstrap/bootstrap-carousel.js"></script>
    <script src="bootstrap/bootstrap-typeahead.js"></script>
    
    <script src="js/main.js"></script>
  
    <script type="text/javascript">
    $(document).ready(function() {
        $('[data-toggle=tooltip]').tooltip();
    });
    </script>
</body>
</html>